﻿#define TEST_BASED_ON_SAMPLE_CODE

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Windows.DataPresenter;



namespace GridTestApp
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        public class GridElement
        {
            public string Field_1 { get{ return "Field 1"; } }
            public string Field_2 { get{ return "Field 2"; } }
            public string Field_3 { get{ return "Field 3"; } }
            public string Field_4 { get{ return "Field 4"; } }
            public string Field_5 { get{ return "Field 5"; } }
        }

        public ObservableCollection<GridElement> m_GridElements = new ObservableCollection<GridElement>();


        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            if (m_DataGrid.FieldLayouts.Count == 0)
                m_DataGrid.FieldLayouts.Add(new FieldLayout());

            FieldLayout theFieldLayout = m_DataGrid.FieldLayouts[0];
            theFieldLayout.Fields.Clear();

            m_DataGrid.FieldLayoutSettings.AutoArrangeCells = AutoArrangeCells.Never;

            // Create the fields
            for (int iField = 0; iField < 5; iField++)
            {
                // Create the new field (Column)
                Field currColField = new Field();

                // Assign the label presenter
                currColField.Label = "Field " + (iField + 1);

                //// Bind
                currColField.Name = "Field_" + (iField + 1);

                // Set the sequence number
                currColField.Column = iField;

                // Add the new field to the field layout
                theFieldLayout.Fields.Add(currColField);
            }

            // Create the data
            for (int iRow = 0; iRow < 10; iRow++)
            {
                m_GridElements.Add(new GridElement());
            }

            // Apply the data
            m_DataGrid.DataSource = m_GridElements;
        }



        protected override void OnRenderSizeChanged(SizeChangedInfo info)
#if TEST_BASED_ON_SAMPLE_CODE
        {
            base.OnRenderSizeChanged(info);

            if (this.m_DataGrid != null &&
                this.m_DataGrid.DefaultFieldLayout != null)
            {
                double newCellWidth = this.m_DataGrid.DefaultFieldLayout.Fields[0].CellWidthResolved + 10;

                this.m_DataGrid.DefaultFieldLayout.Fields[0].Settings.CellMinWidth = newCellWidth;

                this.m_DataGrid.DefaultFieldLayout.Fields[0].Settings.CellMaxWidth = newCellWidth;

                this.m_DataGrid.DefaultFieldLayout.Fields[0].Settings.CellWidth = newCellWidth;


                double newLabelWidth = this.m_DataGrid.DefaultFieldLayout.Fields[0].LabelWidthResolved + 10;

                this.m_DataGrid.DefaultFieldLayout.Fields[0].Settings.LabelMaxWidth = newLabelWidth;

                this.m_DataGrid.DefaultFieldLayout.Fields[0].Settings.LabelMinWidth = newLabelWidth;

                this.m_DataGrid.DefaultFieldLayout.Fields[0].Settings.LabelWidth = newLabelWidth;
            }
        }
#else
        {
            base.OnRenderSizeChanged(info);


            // Go through all of the fields to determine how many are being displayed
            double dAvailableWidth = info.NewSize.Width;
            int nFieldsToAdjust = 0;
            if (m_DataGrid.FieldLayouts.Count > 0)
            {
                FieldLayout currFieldLayout = m_DataGrid.FieldLayouts[0];
                foreach (Field currField in currFieldLayout.Fields)
                {
                    if (currField.Visibility == Visibility.Visible)
                    {
                        nFieldsToAdjust++;

                        // Account for separation lines
                        dAvailableWidth -= 4;
                    }
                }
            }

            if (nFieldsToAdjust > 0)
            {
                double dWidthPerCol = dAvailableWidth / nFieldsToAdjust;
                if (dWidthPerCol > 1)
                {
                    FieldLayout currFieldLayout = m_DataGrid.FieldLayouts[0];
                    foreach (Field currColField in currFieldLayout.Fields)
                    {
                        if (currColField.Visibility == Visibility.Visible)
                        {
                            currColField.Settings.CellMinWidth = dWidthPerCol;
                            currColField.Settings.CellMaxWidth = dWidthPerCol;
                            currColField.Settings.CellWidth = dWidthPerCol;

                            currColField.Settings.LabelMinWidth = dWidthPerCol;
                            currColField.Settings.LabelMaxWidth = dWidthPerCol;
                            currColField.Settings.LabelWidth = dWidthPerCol;
                        }
                    }
                }
            }
        }
#endif

    }
}
